package com.wechat.common.utils;

import java.io.UnsupportedEncodingException;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;
import java.security.SecureRandom;

import javax.crypto.BadPaddingException;
import javax.crypto.Cipher;
import javax.crypto.IllegalBlockSizeException;
import javax.crypto.KeyGenerator;
import javax.crypto.NoSuchPaddingException;
import javax.crypto.SecretKey;
import javax.crypto.spec.SecretKeySpec;

import org.apache.commons.codec.binary.Base64;


public final class AESUtil extends BaseUtils{
    // 定义加密算法
    private static final String ALGORITHM = "AES";

    private AESUtil() {
    }

    /**
     * @param strCustomKey 自定义密钥，对于AES算法，请输入16||24||32个ASCII字符
     * @return 密钥对象
     * @throws UnsupportedEncodingException
     */
    public static SecretKey createKey(String strCustomKey) throws UnsupportedEncodingException {
        SecretKey desKey = null;

        desKey = new SecretKeySpec(strCustomKey.getBytes("UTF-8"), ALGORITHM);

        return desKey;
    }

    /**
     * 加密数据
     * 
     * @param para 要加密的数据
     * @param deskey 密钥
     * @return 加密后的密文
     * @throws UnsupportedEncodingException
     */
    public static String encrypt(String content, String password) {
        try {
            KeyGenerator kgen = KeyGenerator.getInstance("AES");
            SecureRandom secureRandom = SecureRandom.getInstance("SHA1PRNG");
            secureRandom.setSeed(password.getBytes());
            kgen.init(128, secureRandom);
            SecretKey secretKey = kgen.generateKey();
            byte[] enCodeFormat = secretKey.getEncoded();
            SecretKeySpec key = new SecretKeySpec(enCodeFormat, "AES");
            Cipher cipher = Cipher.getInstance("AES");// 创建密码器   
            byte[] byteContent = content.getBytes("utf-8");
            cipher.init(Cipher.ENCRYPT_MODE, key);// 初始化   
            byte[] result = cipher.doFinal(byteContent); 
            return new String(new Base64().encodeToString(result)); // 加密   
        } catch (NoSuchAlgorithmException e) {
            log.error(e);
        } catch (NoSuchPaddingException e) {
            log.error(e);
        } catch (InvalidKeyException e) {
            log.error(e);
        } catch (UnsupportedEncodingException e) {
            log.error(e);
        } catch (IllegalBlockSizeException e) {
            log.error(e);
        } catch (BadPaddingException e) {
            log.error(e);
        }
        return null;
    }

    /**
     * 解密
     * 
     * @param content 密文
     * @param password 密钥
     * @return 解密后的内容
     */
    public static String decryptStr(String content, String password){
    	byte[] byteContent = Base64.decodeBase64(content);
		byte[] result = decrypt(byteContent,password);
		return new String(result);
    }
    
    /**
     * 解密
     * 
     * @param content 密文
     * @param password 密钥
     * @return 解密后的内容
     */
    public static byte[] decrypt(byte[] content, String password) {
        try {
            KeyGenerator kgen = KeyGenerator.getInstance("AES");
            SecureRandom secureRandom = SecureRandom.getInstance("SHA1PRNG");
            secureRandom.setSeed(password.getBytes());
            kgen.init(128, secureRandom);
            SecretKey secretKey = kgen.generateKey();
            byte[] enCodeFormat = secretKey.getEncoded();
            SecretKeySpec key = new SecretKeySpec(enCodeFormat, "AES");
            Cipher cipher = Cipher.getInstance("AES");// 创建密码器   
            cipher.init(Cipher.DECRYPT_MODE, key);// 初始化   
            byte[] result = cipher.doFinal(content);
            return result; // 加密   
        } catch (NoSuchAlgorithmException e) {
            log.error("AES解密错误",e);
        } catch (NoSuchPaddingException e) {
            log.error("AES解密错误",e);
        } catch (InvalidKeyException e) {
            log.error("AES解密错误",e);
        } catch (IllegalBlockSizeException e) {
            log.error("AES解密错误",e);
        } catch (BadPaddingException e) {
            log.error("AES解密错误",e);
        }
        return null;
    }

    /**
     * 将二进制转换成16进制
     * 
     * @param buf
     * @return
     */
    public static String parseByte2HexStr(byte buf[]) {
        StringBuffer sb = new StringBuffer();
        for (int i = 0; i < buf.length; i++) {
            String hex = Integer.toHexString(buf[i] & 0xFF);
            if (hex.length() == 1) {
                hex = '0' + hex;
            }
            sb.append(hex.toUpperCase());
        }
        return sb.toString();
    }

    /**
     * 将16进制转换为二进制
     * 
     * @param hexStr
     * @return 转换后结果
     */
    public static byte[] parseHexStr2Byte(String hexStr) {
        if (hexStr.length() < 1)
            return null;
        byte[] result = new byte[hexStr.length() / 2];
        for (int i = 0; i < hexStr.length() / 2; i++) {
            int high = Integer.parseInt(hexStr.substring(i * 2, i * 2 + 1), 16);
            int low = Integer.parseInt(hexStr.substring(i * 2 + 1, i * 2 + 2), 16);
            result[i] = (byte) (high * 16 + low);
        }
        return result;
    }
}
