/**
 * Copyright &copy; 2012-2016 <a href="https://github.com/thinkgem/jeesite">JeeSite</a> All rights reserved.
 */
package com.wechat.model.dbEntity;

import javax.validation.constraints.NotNull;
import javax.validation.constraints.Pattern;

import org.hibernate.validator.constraints.NotBlank;

/**
 * 单表生成Entity
 * 
 * @author tangwc
 * @version 2018-06-08
 */
public class MdeInvoiceTitle extends BaseEntity {

	private static final long serialVersionUID = 1L;
	
	private String invId; // 动态id
	
	@NotBlank(message = "用户code不能为空|usercode can not be null")
	private String userCode; // 用户id
	
	@NotBlank(message = "发票抬头不能为空|The invoice should not be empty.")
	private String invTitle; // 发票抬头
	
	private String taxationNo; // 税号
	private String ltdAdd; // 公司地址
	private String ltdTel; // 公司电话
	private String openingBank; // 开户行
	private String accountNumber; // 开户账号
	
	@NotBlank(message = "开票内容不能为空|The contents of the invoice must not be empty.")
	private String invContent; // 开票内容
	
	@NotBlank(message = "开票金额不能为空|The amount of the invoice must not be empty.")
	private String invMoney; // 开票金额
	
	@NotBlank(message = "发票收件人姓名不能为空|The name of the consignee can not be blank.")
	private String recipientName; // 收件人姓名
	
	@NotBlank(message = "发票收件人电话不能为空|Invoice recipient's telephone number must not be blank.")
	@Pattern(regexp = "^\\d{11}$", message = "手机号格式不正确|The phone number is not correct.")
	private String recipientTel; // 收件人电话
	
	@NotBlank(message = "发票收件地址不能为空|Invoice receipt address can not be empty.")
	private String recipientAdd; // 收件地址
	
	@NotBlank(message = "发票类型不能为空|Invoice type can not be empty.")
	private String invType; // 类型区分[1-普票；2-增值税发票]

	// 附加字段
	@NotNull(message = "订单ID不能为空|Order ID cannot be empty.")
	private String orderId;
	
	public MdeInvoiceTitle() {
		super();
	}

	// @Length(min=1, max=11, message="动态id长度必须介于 1 和 11 之间")
	public String getInvId() {
		return invId;
	}

	public void setInvId(String invId) {
		this.invId = invId;
	}

	// @NotNull(message="用户id不能为空")
	public String getUserCode() {
		return userCode;
	}

	public void setUserCode(String userCode) {
		this.userCode = userCode;
	}

	// @Length(min=1, max=50, message="发票抬头长度必须介于 1 和 50 之间")
	public String getInvTitle() {
		return invTitle;
	}

	public void setInvTitle(String invTitle) {
		this.invTitle = invTitle;
	}

	// @Length(min=1, max=20, message="税号长度必须介于 1 和 20 之间")
	public String getTaxationNo() {
		return taxationNo;
	}

	public void setTaxationNo(String taxationNo) {
		this.taxationNo = taxationNo;
	}

	// @Length(min=0, max=100, message="公司地址长度必须介于 0 和 100 之间")
	public String getLtdAdd() {
		return ltdAdd;
	}

	public void setLtdAdd(String ltdAdd) {
		this.ltdAdd = ltdAdd;
	}

	// @Length(min=0, max=12, message="公司电话长度必须介于 0 和 12 之间")
	public String getLtdTel() {
		return ltdTel;
	}

	public void setLtdTel(String ltdTel) {
		this.ltdTel = ltdTel;
	}

	// @Length(min=0, max=100, message="开户行长度必须介于 0 和 100 之间")
	public String getOpeningBank() {
		return openingBank;
	}

	public void setOpeningBank(String openingBank) {
		this.openingBank = openingBank;
	}

	// @Length(min=0, max=25, message="开户账号长度必须介于 0 和 25 之间")
	public String getAccountNumber() {
		return accountNumber;
	}

	public void setAccountNumber(String accountNumber) {
		this.accountNumber = accountNumber;
	}

	// @Length(min=1, max=50, message="开票内容长度必须介于 1 和 50 之间")
	public String getInvContent() {
		return invContent;
	}

	public void setInvContent(String invContent) {
		this.invContent = invContent;
	}

	public String getInvMoney() {
		return invMoney;
	}

	public void setInvMoney(String invMoney) {
		this.invMoney = invMoney;
	}

	// @Length(min=1, max=50, message="收件人姓名长度必须介于 1 和 50 之间")
	public String getRecipientName() {
		return recipientName;
	}

	public void setRecipientName(String recipientName) {
		this.recipientName = recipientName;
	}

	// @Length(min=1, max=12, message="收件人电话长度必须介于 1 和 12 之间")
	public String getRecipientTel() {
		return recipientTel;
	}

	public void setRecipientTel(String recipientTel) {
		this.recipientTel = recipientTel;
	}

	// @Length(min=1, max=100, message="收件地址长度必须介于 1 和 100 之间")
	public String getRecipientAdd() {
		return recipientAdd;
	}

	public void setRecipientAdd(String recipientAdd) {
		this.recipientAdd = recipientAdd;
	}

	// @Length(min=1, max=1, message="类型区分[1-普票；2-增值税发票]长度必须介于 1 和 1 之间")
	public String getInvType() {
		return invType;
	}

	public void setInvType(String invType) {
		this.invType = invType;
	}

	public String getOrderId() {
		return orderId;
	}

	public void setOrderId(String orderId) {
		this.orderId = orderId;
	}
	
}