/**
 * Copyright &copy; 2012-2016 <a href="https://github.com/thinkgem/jeesite">JeeSite</a> All rights reserved.
 */
package com.wechat.model.dbEntity;

import org.hibernate.validator.constraints.Length;
import java.util.Date;
import com.fasterxml.jackson.annotation.JsonFormat;
import javax.validation.constraints.NotNull;


/**
 * 券类别Entity
 * @author tangwc
 * @version 2018-09-09
 */
public class MdeTicketCategory extends BaseEntity {
	
	private static final long serialVersionUID = 1L;
	private String tcCode;		// code(uuid)
	private String issuedType;		// 发行类型[1-注册赠送；2-营销]
	private String identityFlag;		// 可使用身份标识[0-个人；1-企业]
	private String receiveFlag;		// 可领用身份标识[0-个人；1-企业；9-不限]
	private String shareFlag;		// 可分享标识[0-不可分享；1-可分享]
	private Date receiveFrom;		// 开始领用时间
	private Date receiveTo;		// 领用结束时间
	private Date availableFrom;		// 使用时间from
	private Date availableTo;		// 使用时间to
	private String title;		// 标题
	private String description;		// 使用说明
	private String rule;		// 使用规则
	private String titleEn;		// 标题_英文
	private String descriptionEn;		// 使用说明_英文
	private String ruleEn;		// 使用规则_英文
	private String issuedNum;		// 发行总量(-1表示不限)
	private String leftNum;		// 剩余数量
	private String money;		// 券面价格
	
	public MdeTicketCategory() {
		super();
	}

	@Length(min=1, max=255, message="字段长度超过限制|Field length exceeds limit")
	public String getTcCode() {
		return tcCode;
	}

	public void setTcCode(String tcCode) {
		this.tcCode = tcCode;
	}
	
	@Length(min=1, max=1, message="字段长度超过限制|Field length exceeds limit")
	public String getIssuedType() {
		return issuedType;
	}

	public void setIssuedType(String issuedType) {
		this.issuedType = issuedType;
	}
	
	@Length(min=1, max=1, message="字段长度超过限制|Field length exceeds limit")
	public String getIdentityFlag() {
		return identityFlag;
	}

	public void setIdentityFlag(String identityFlag) {
		this.identityFlag = identityFlag;
	}
	
	@Length(min=1, max=1, message="字段长度超过限制|Field length exceeds limit")
	public String getReceiveFlag() {
		return receiveFlag;
	}

	public void setReceiveFlag(String receiveFlag) {
		this.receiveFlag = receiveFlag;
	}
	
	@Length(min=1, max=1, message="字段长度超过限制|Field length exceeds limit")
	public String getShareFlag() {
		return shareFlag;
	}

	public void setShareFlag(String shareFlag) {
		this.shareFlag = shareFlag;
	}
	
	@JsonFormat(pattern = "yyyy-MM-dd", timezone="GMT+8")
	@NotNull(message="开始领用时间不能为空|ReceiveFrom can not be empty.")
	public Date getReceiveFrom() {
		return receiveFrom;
	}

	public void setReceiveFrom(Date receiveFrom) {
		this.receiveFrom = receiveFrom;
	}
	
	@JsonFormat(pattern = "yyyy-MM-dd", timezone="GMT+8")
	@NotNull(message="领用结束时间不能为空|ReceiveTo can not be empty.")
	public Date getReceiveTo() {
		return receiveTo;
	}

	public void setReceiveTo(Date receiveTo) {
		this.receiveTo = receiveTo;
	}
	
	@JsonFormat(pattern = "yyyy-MM-dd", timezone="GMT+8")
	@NotNull(message="使用时间不能为空|AvailableFrom can not be empty.")
	public Date getAvailableFrom() {
		return availableFrom;
	}

	public void setAvailableFrom(Date availableFrom) {
		this.availableFrom = availableFrom;
	}
	
	@JsonFormat(pattern = "yyyy-MM-dd", timezone="GMT+8")
	@NotNull(message="使用时间不能为空|AvailableTo can not be empty.")
	public Date getAvailableTo() {
		return availableTo;
	}

	public void setAvailableTo(Date availableTo) {
		this.availableTo = availableTo;
	}
	
	@Length(min=1, max=50, message="字段长度超过限制|Field length exceeds limit")
	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}
	
	@Length(min=1, max=50, message="字段长度超过限制|Field length exceeds limit")
	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}
	
	@Length(min=1, max=200, message="字段长度超过限制|Field length exceeds limit")
	public String getRule() {
		return rule;
	}

	public void setRule(String rule) {
		this.rule = rule;
	}
	
	@Length(min=1, max=100, message="字段长度超过限制|Field length exceeds limit")
	public String getTitleEn() {
		return titleEn;
	}

	public void setTitleEn(String titleEn) {
		this.titleEn = titleEn;
	}
	
	@Length(min=1, max=300, message="字段长度超过限制|Field length exceeds limit")
	public String getDescriptionEn() {
		return descriptionEn;
	}

	public void setDescriptionEn(String descriptionEn) {
		this.descriptionEn = descriptionEn;
	}
	
	@Length(min=1, max=300, message="字段长度超过限制|Field length exceeds limit")
	public String getRuleEn() {
		return ruleEn;
	}

	public void setRuleEn(String ruleEn) {
		this.ruleEn = ruleEn;
	}
	
	@Length(min=1, max=11, message="字段长度超过限制|Field length exceeds limit")
	public String getIssuedNum() {
		return issuedNum;
	}

	public void setIssuedNum(String issuedNum) {
		this.issuedNum = issuedNum;
	}
	
	public String getLeftNum() {
		return leftNum;
	}

	public void setLeftNum(String leftNum) {
		this.leftNum = leftNum;
	}
	
	@Length(min=1, max=11, message="字段长度超过限制|Field length exceeds limit")
	public String getMoney() {
		return money;
	}

	public void setMoney(String money) {
		this.money = money;
	}
	
}