package com.wechat.service;

import java.util.List;

import javax.annotation.Resource;

import org.springframework.stereotype.Service;

import com.wechat.common.utils.StringsUtils;
import com.wechat.dao.FaqInfoDao;
import com.wechat.model.dbEntity.TdtgFaqInfo;


/**
 * FAQ服务提供类
 * 
 */
@Service
public class FaqService {

    @Resource
    private FaqInfoDao faqInfoDao;
    
    /**
     * 通过用户发送的信息，检索FAQ所有内容
     * 
     * @param keyWord 用户发送的信息
     * @return
     */
    public List<TdtgFaqInfo> getAllInfoByKeyWord(String keyWord) {
        return faqInfoDao.getInfoList(keyWord);
    }
    
    /**
     * 通过用户发送的信息，检索FAQ内容
     * 
     * @param keyWord 用户发送的信息
     * @return
     */
    public TdtgFaqInfo getInfoByKeyWord(String keyWord) {
    	List<TdtgFaqInfo> infoList = faqInfoDao.getInfoList(keyWord);
    	TdtgFaqInfo faqInfo = new TdtgFaqInfo();
    	if(StringsUtils.isListEmpty(infoList))
    	{
    		faqInfo = null;
    	}
    	else
    	{
    		//随机取一个关键词进行回复
    		faqInfo = infoList.get(StringsUtils.getOneRandomNum(infoList.size()));
    	}
    	return faqInfo;
    }
    
    /**
     * 通过id检索FAQ内容
     * 
     * @param keyWord 用户发送的信息
     * @return
     */
    public TdtgFaqInfo getInfoById(int id) {
        return faqInfoDao.getInfoById(id);
    }
    
}
